#ifndef _MLA_WEB_H_
#define _MLA_WEB_H_

#include "mstate.h"
#include "mconfig.h"
#include "generate.h"
#include "template.h"

mhash *get_visit_path_length(mconfig *ext_conf, mhash *h);
mhash *get_visit_duration(mconfig *ext_conf, mhash *h, mstate *state);
char * generate_web(mconfig * ext_conf, mstate * state, const char *current, int max);
int mplugins_output_generate_history_output_web(mconfig *ext_conf, mlist *history, tmpl_main *tmpl);

int register_reports_web(mconfig * ext_conf, tmpl_reports *reports);
void generate_web_cleanup(mconfig * ext_conf);
/**
 * Parse a whole prepared table row, and then clears all possible used
 * subtemplates
*/
void parse_table_row(tmpl_main *tmpl);

#endif
